pygeodesy.ltpTuples.Local9Tuple

Package pygeodesy :: Module ltpTuples :: Class Local9Tuple |
[frames] | no frames]

# Class Local9Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Local9Tuple

Known Subclasses:
  - ChLV9Tuple

9-Tuple `(x, y, z, lat, lon, height, ltp, ecef, M)` with local `x`, `y`, `z` all in `meter`, geodetic `lat`, `lon`, `height`, local tangent plane `ltp` (Ltp), `ecef` (Ecef9Tuple) with geocentric `x`, `y`, `z`, geodetic `lat`, `lon`, `height` and concatenated rotation matrix `M` (EcefMatrix) or `None`.

Instance Methods
toAer(self, Aer=None, **name_Aer_kwds) Get the local Azimuth, Elevation, slant Range (AER) components. |
toCartesian(self, Cartesian=None, **name_Cartesian_kwds) Convert this local to geocentric `(x, y, z)` (ECEF). |
toEnu(self, Enu=None, **name_Enu_kwds) Get the local East, North, Up (ENU) components. |
toLatLon(self, LatLon=None, **name_LatLon_kwds) Convert this local to geodetic `(lat, lon, height)`. |
toNed(self, Ned=None, **name_Ned_kwds) Get the local North, East, Down (NED) components. |
toXyz(self, Xyz=None, **name_Xyz_kwds) Get the local X, Y, Z (XYZ) components. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
| azimuth Get the local Azimuth, bearing from North (`degrees360`).
| down Get the local Down, `-z` component (`meter`).
| east Get the local East, `x` component (`meter`).
| elevation Get the local Elevation, tilt above horizon (`degrees90`).
| groundrange Get the local ground range, distance (`meter`).
| lam Get the geodetic longitude in `radians` (`float`).
| latlon Get the geodetic lat-, longitude in `degrees` (LatLon2Tuple`(lat, lon)`).
| latlonheight Get the geodetic lat-, longitude in `degrees` and height (LatLon3Tuple`(lat, lon, height)`).
| north Get the local North, `y` component (`meter`).
| phi Get the geodetic latitude in `radians` (`float`).
| philam Get the geodetic lat-, longitude in `radians` (PhiLam2Tuple`(phi, lam)`).
| philamheight Get the geodetic lat-, longitude in `radians` and height (PhiLam3Tuple`(phi, lam, height)`).
| slantrange Get the local slant Range, distance (`meter`).
| up Get the local Up, `z` component (`meter`).
| xyz Get the local `(X, Y, Z)` components (Vector3Tuple`(x, y, z)`).
| xyzLocal Get this Local9Tuple as an XyzLocal.
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toAer (self, Aer=None, **name_Aer_kwds) |
Get the local Azimuth, Elevation, slant Range (AER) components. Arguments: `Aer` - Class to return AER (Aer) or `None`. `name_Aer_kwds` - Optional `name=NN` (`str`) and optionally, additional Aer keyword arguments, ignored if `Aer is None`. Returns: An `Aer` instance or an Aer4Tuple`(azimuth, elevation, slantrange, ltp)` if `Aer is None`. Raises: `TypeError` - Invalid `Aer` or `name_Aer_kwds` item.

### toCartesian (self, Cartesian=None, **name_Cartesian_kwds) |
Convert this local to geocentric `(x, y, z)` (ECEF). Arguments: `Cartesian` - Optional geocentric class to return `(x, y, z)` (`Cartesian`) or `None`. `name_Cartesian_kwds` - Optional `name=NN` (`str`) and optionally, additional `Cartesian` keyword arguments, ignored if `Cartesian is None`. Returns: A `Cartesian(x, y, z, **Cartesian_kwds)` instance or a Vector4Tuple`(x, y, z, h)` if `Cartesian is None`. Raises: `TypeError` - Invalid `Cartesian` or `name_Cartesian_kwds` item.

### toEnu (self, Enu=None, **name_Enu_kwds) |
Get the local East, North, Up (ENU) components. Arguments: `Enu` - Class to return ENU (Enu) or `None`. `name_Enu_kwds` - Optional `name=NN` (`str`) and optionally, additional Enu keyword arguments, ignored if `Enu is None`. Returns: ENU as an Enu instance or if `Enu is None`, an Enu4Tuple`(east, north, up, ltp)`. Raises: `TypeError` - Invalid `Enu` or `name_Enu_kwds` item.

### toLatLon (self, LatLon=None, **name_LatLon_kwds) |
Convert this local to geodetic `(lat, lon, height)`. Arguments: `LatLon` - Optional geodetic class to return `(lat, lon, height)` (`LatLon`) or `None`. `name_LatLon_kwds` - Optional `name=NN` (`str`) and optionally, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: An `LatLon(lat, lon, **LatLon_kwds)` instance or if `LatLon is None`, a LatLon4Tuple`(lat, lon, height, datum)` or LatLon3Tuple`(lat, lon, height)` if `datum` is specified or not. Raises: `TypeError` - Invalid `LatLon` or `name_LatLon_kwds`.

### toNed (self, Ned=None, **name_Ned_kwds) |
Get the local North, East, Down (NED) components. Arguments: `Ned` - Class to return NED (Ned) or `None`. `name_Ned_kwds` - Optional `name=NN` (`str`) and optionally, additional Ned keyword arguments, ignored if `Ned is None`. Returns: An `Ned` instance or an Ned4Tuple`(north, east, down, ltp)` if `Ned is None`. Raises: `TypeError` - Invalid `Ned` or `name_Ned_kwds` item.

### toXyz (self, Xyz=None, **name_Xyz_kwds) |
Get the local X, Y, Z (XYZ) components. Arguments: `Xyz` - Class to return XYZ (XyzLocal) or `None`. `name_Xyz_kwds` - Optional `name=NN` (`str`) and optionally, additional `Xyz` keyword arguments, ignored if `Xyz is None`. Returns: An `Xyz` instance or an Xyz4Tuple`(x, y, z, ltp)` if `Xyz is None`. Raises: `TypeError` - Invalid `Xyz` or `name_Xyz_kwds` item.

Property Details

### azimuth Get the local Azimuth, bearing from North (`degrees360`). Get method: azimuth(self) - Get the local Azimuth, bearing from North (`degrees360`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### down Get the local Down, `-z` component (`meter`). Get method: down(self) - Get the local Down, `-z` component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### east Get the local East, `x` component (`meter`). Get method: east(self) - Get the local East, `x` component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### elevation Get the local Elevation, tilt above horizon (`degrees90`). Get method: elevation(self) - Get the local Elevation, tilt above horizon (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### groundrange Get the local ground range, distance (`meter`). Get method: groundrange(self) - Get the local ground range, distance (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lam Get the geodetic longitude in `radians` (`float`). Get method: lam(self) - Get the geodetic longitude in `radians` (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlon Get the geodetic lat-, longitude in `degrees` (LatLon2Tuple`(lat, lon)`). Get method: latlon(self) - Get the geodetic lat-, longitude in `degrees` (LatLon2Tuple`(lat, lon)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlonheight Get the geodetic lat-, longitude in `degrees` and height (LatLon3Tuple`(lat, lon, height)`). Get method: latlonheight(self) - Get the geodetic lat-, longitude in `degrees` and height (LatLon3Tuple`(lat, lon, height)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### north Get the local North, `y` component (`meter`). Get method: north(self) - Get the local North, `y` component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### phi Get the geodetic latitude in `radians` (`float`). Get method: phi(self) - Get the geodetic latitude in `radians` (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philam Get the geodetic lat-, longitude in `radians` (PhiLam2Tuple`(phi, lam)`). Get method: philam(self) - Get the geodetic lat-, longitude in `radians` (PhiLam2Tuple`(phi, lam)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philamheight Get the geodetic lat-, longitude in `radians` and height (PhiLam3Tuple`(phi, lam, height)`). Get method: philamheight(self) - Get the geodetic lat-, longitude in `radians` and height (PhiLam3Tuple`(phi, lam, height)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### slantrange Get the local slant Range, distance (`meter`). Get method: slantrange(self) - Get the local slant Range, distance (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### up Get the local Up, `z` component (`meter`). Get method: up(self) - Get the local Up, `z` component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyz Get the local `(X, Y, Z)` components (Vector3Tuple`(x, y, z)`). Get method: xyz(self) - Get the local `(X, Y, Z)` components (Vector3Tuple`(x, y, z)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyzLocal Get this Local9Tuple as an XyzLocal. Get method: xyzLocal(self) - Get this Local9Tuple as an XyzLocal. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.